import logging

from markdown import Extension
from markdown.inlinepatterns import Pattern
from requests_oauthlib import OAuth1Session

TWITTER_LINK_RE = r"https?://twitter.com/([^/]+)/status(es)?/(?P<tweet_id>\d+)"


class TwitterLinkPattern(Pattern):

    def __init__(self, pattern, markdown_instance=None, client=None):
        Pattern.__init__(self, pattern, markdown_instance)
        self.client = client

    def get_html(self, tweet_id):
        response = self.client.get("https://api.twitter.com/1.1/statuses/oembed.json", params={
            'id': tweet_id,
        })
        result = response.json()
        if 'html' in result:
            return result['html']
        else:
            for err in result['errors']:
                logging.warning(err['message'])
        return "[Tweet oembed error]"

    def handleMatch(self, m):
        tweet_id = m.group('tweet_id')
        html = self.get_html(tweet_id)
        placeholder = self.markdown.htmlStash.store(html, safe=True)
        return placeholder


class TwitterExtension(Extension):
    def __init__(self, *args, **kwargs):
        self.twitter_settings = kwargs.pop('twitter_settings')
        Extension.__init__(self, *args, **kwargs)

    def get_client(self):
        client = OAuth1Session(
            self.twitter_settings['CONSUMER_KEY'],
            client_secret=self.twitter_settings['CONSUMER_SECRET'],
            resource_owner_key=self.twitter_settings['ACCESS_TOKEN'],
            resource_owner_secret=self.twitter_settings['ACCESS_TOKEN_SECRET']
        )
        return client

    def extendMarkdown(self, md, md_globals):
        pattern = TwitterLinkPattern(TWITTER_LINK_RE, md, self.get_client())
        md.inlinePatterns.add('twitter_link', pattern, '<reference')



import os
import logging
import ConfigParser


def get_twitter_settings():
    TWITTER_SETTINGS = {
        'CONSUMER_KEY': '',
        'CONSUMER_SECRET': '',
        'ACCESS_TOKEN': '',
        'ACCESS_TOKEN_SECRET': '',
    }

    try:
        config = ConfigParser.ConfigParser()
        config.readfp(open(os.path.expanduser('~/.mdx_twitter.cfg')))
        for field in TWITTER_SETTINGS.keys():
            TWITTER_SETTINGS[field] = config.get('Twitter', field)
    except IOError:
        logging.warning('~/.mdx_twitter.cfg is missing')
    return TWITTER_SETTINGS



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os
import sys


from setuptools import setup

import mdx_twitter

if sys.argv[-1] == 'publish':
    os.system('python setup.py sdist upload')
    sys.exit()

readme = open('README.rst').read()
history = open('HISTORY.rst').read().replace('.. :changelog:', '')

setup(
    name='mdx-twitter',
    version=mdx_twitter.__version__,
    description='Markdown extension for embedding tweets',
    long_description=readme + '\n\n' + history,
    author='Andrii Kurinnyi',
    author_email='andrew@marpasoft.com',
    url='https://github.com/zen4ever/mdx-twitter',
    packages=[
        'mdx_twitter',
    ],
    include_package_data=True,
    install_requires=[
        'Markdown',
        'requests-oauthlib>=0.3.3',
    ],
    tests_require=[
        'httmock',
    ],
    license="BSD",
    zip_safe=False,
    keywords='Markdown, Twitter',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Natural Language :: English',
        "Programming Language :: Python :: 2",
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
    ],
    test_suite='tests',
)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

__author__ = 'Andrii Kurinnyi'
__email__ = 'andrew@marpasoft.com'
__version__ = '0.1.1'


def makeExtension(configs=None):
    from .extension import TwitterExtension
    from .settings import get_twitter_settings
    return TwitterExtension(configs=configs, twitter_settings=get_twitter_settings())
